import type { BaseContract, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../../../../../../common";
export interface IVRFMigratableConsumerV2PlusInterface extends Interface {
    getFunction(nameOrSignature: "setCoordinator"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "CoordinatorSet"): EventFragment;
    encodeFunctionData(functionFragment: "setCoordinator", values: [AddressLike]): string;
    decodeFunctionResult(functionFragment: "setCoordinator", data: BytesLike): Result;
}
export declare namespace CoordinatorSetEvent {
    type InputTuple = [vrfCoordinator: AddressLike];
    type OutputTuple = [vrfCoordinator: string];
    interface OutputObject {
        vrfCoordinator: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface IVRFMigratableConsumerV2Plus extends BaseContract {
    connect(runner?: ContractRunner | null): IVRFMigratableConsumerV2Plus;
    waitForDeployment(): Promise<this>;
    interface: IVRFMigratableConsumerV2PlusInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    setCoordinator: TypedContractMethod<[
        vrfCoordinator: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "setCoordinator"): TypedContractMethod<[vrfCoordinator: AddressLike], [void], "nonpayable">;
    getEvent(key: "CoordinatorSet"): TypedContractEvent<CoordinatorSetEvent.InputTuple, CoordinatorSetEvent.OutputTuple, CoordinatorSetEvent.OutputObject>;
    filters: {
        "CoordinatorSet(address)": TypedContractEvent<CoordinatorSetEvent.InputTuple, CoordinatorSetEvent.OutputTuple, CoordinatorSetEvent.OutputObject>;
        CoordinatorSet: TypedContractEvent<CoordinatorSetEvent.InputTuple, CoordinatorSetEvent.OutputTuple, CoordinatorSetEvent.OutputObject>;
    };
}
