import type { BaseContract, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../../../common";
export interface IVeaInboxInterface extends Interface {
    getFunction(nameOrSignature: "saveSnapshot" | "sendMessage"): FunctionFragment;
    encodeFunctionData(functionFragment: "saveSnapshot", values?: undefined): string;
    encodeFunctionData(functionFragment: "sendMessage", values: [AddressLike, BytesLike, BytesLike]): string;
    decodeFunctionResult(functionFragment: "saveSnapshot", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendMessage", data: BytesLike): Result;
}
export interface IVeaInbox extends BaseContract {
    connect(runner?: ContractRunner | null): IVeaInbox;
    waitForDeployment(): Promise<this>;
    interface: IVeaInboxInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    saveSnapshot: TypedContractMethod<[], [void], "nonpayable">;
    sendMessage: TypedContractMethod<[
        _to: AddressLike,
        _fnSelection: BytesLike,
        _data: BytesLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "saveSnapshot"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "sendMessage"): TypedContractMethod<[
        _to: AddressLike,
        _fnSelection: BytesLike,
        _data: BytesLike
    ], [
        bigint
    ], "nonpayable">;
    filters: {};
}
