import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../common";
export type ClaimStruct = {
    stateRoot: BytesLike;
    claimer: AddressLike;
    timestampClaimed: BigNumberish;
    timestampVerification: BigNumberish;
    blocknumberVerification: BigNumberish;
    honest: BigNumberish;
    challenger: AddressLike;
};
export type ClaimStructOutput = [
    stateRoot: string,
    claimer: string,
    timestampClaimed: bigint,
    timestampVerification: bigint,
    blocknumberVerification: bigint,
    honest: bigint,
    challenger: string
] & {
    stateRoot: string;
    claimer: string;
    timestampClaimed: bigint;
    timestampVerification: bigint;
    blocknumberVerification: bigint;
    honest: bigint;
    challenger: string;
};
export interface VeaMockInterface extends Interface {
    getFunction(nameOrSignature: "resolveDisputedClaim" | "saveSnapshot" | "sendMessage(bytes32[],uint64,address,bytes)" | "sendMessage(address,bytes4,bytes)"): FunctionFragment;
    encodeFunctionData(functionFragment: "resolveDisputedClaim", values: [BigNumberish, BytesLike, ClaimStruct]): string;
    encodeFunctionData(functionFragment: "saveSnapshot", values?: undefined): string;
    encodeFunctionData(functionFragment: "sendMessage(bytes32[],uint64,address,bytes)", values: [BytesLike[], BigNumberish, AddressLike, BytesLike]): string;
    encodeFunctionData(functionFragment: "sendMessage(address,bytes4,bytes)", values: [AddressLike, BytesLike, BytesLike]): string;
    decodeFunctionResult(functionFragment: "resolveDisputedClaim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "saveSnapshot", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendMessage(bytes32[],uint64,address,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendMessage(address,bytes4,bytes)", data: BytesLike): Result;
}
export interface VeaMock extends BaseContract {
    connect(runner?: ContractRunner | null): VeaMock;
    waitForDeployment(): Promise<this>;
    interface: VeaMockInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    resolveDisputedClaim: TypedContractMethod<[
        _epoch: BigNumberish,
        _stateRoot: BytesLike,
        _claim: ClaimStruct
    ], [
        void
    ], "nonpayable">;
    saveSnapshot: TypedContractMethod<[], [void], "nonpayable">;
    "sendMessage(bytes32[],uint64,address,bytes)": TypedContractMethod<[
        _proof: BytesLike[],
        _msgId: BigNumberish,
        _to: AddressLike,
        _message: BytesLike
    ], [
        void
    ], "nonpayable">;
    "sendMessage(address,bytes4,bytes)": TypedContractMethod<[
        _to: AddressLike,
        _fnSelector: BytesLike,
        _data: BytesLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "resolveDisputedClaim"): TypedContractMethod<[
        _epoch: BigNumberish,
        _stateRoot: BytesLike,
        _claim: ClaimStruct
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "saveSnapshot"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "sendMessage(bytes32[],uint64,address,bytes)"): TypedContractMethod<[
        _proof: BytesLike[],
        _msgId: BigNumberish,
        _to: AddressLike,
        _message: BytesLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "sendMessage(address,bytes4,bytes)"): TypedContractMethod<[
        _to: AddressLike,
        _fnSelector: BytesLike,
        _data: BytesLike
    ], [
        bigint
    ], "nonpayable">;
    filters: {};
}
