import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../../../common";
export declare namespace VRFV2PlusClient {
    type RandomWordsRequestStruct = {
        keyHash: BytesLike;
        subId: BigNumberish;
        requestConfirmations: BigNumberish;
        callbackGasLimit: BigNumberish;
        numWords: BigNumberish;
        extraArgs: BytesLike;
    };
    type RandomWordsRequestStructOutput = [
        keyHash: string,
        subId: bigint,
        requestConfirmations: bigint,
        callbackGasLimit: bigint,
        numWords: bigint,
        extraArgs: string
    ] & {
        keyHash: string;
        subId: bigint;
        requestConfirmations: bigint;
        callbackGasLimit: bigint;
        numWords: bigint;
        extraArgs: string;
    };
}
export interface ChainlinkVRFCoordinatorV2MockInterface extends Interface {
    getFunction(nameOrSignature: "acceptSubscriptionOwnerTransfer" | "addConsumer" | "cancelSubscription" | "createSubscription" | "fulfillRandomWords" | "fundSubscription" | "fundSubscriptionWithNative" | "getActiveSubscriptionIds" | "getSubscription" | "pendingRequestExists" | "removeConsumer" | "requestRandomWords" | "requestSubscriptionOwnerTransfer"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "RandomWordsFulfilled" | "RandomWordsRequested"): EventFragment;
    encodeFunctionData(functionFragment: "acceptSubscriptionOwnerTransfer", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "addConsumer", values: [BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "cancelSubscription", values: [BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "createSubscription", values?: undefined): string;
    encodeFunctionData(functionFragment: "fulfillRandomWords", values: [BigNumberish, AddressLike, BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "fundSubscription", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "fundSubscriptionWithNative", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getActiveSubscriptionIds", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getSubscription", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "pendingRequestExists", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "removeConsumer", values: [BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "requestRandomWords", values: [VRFV2PlusClient.RandomWordsRequestStruct]): string;
    encodeFunctionData(functionFragment: "requestSubscriptionOwnerTransfer", values: [BigNumberish, AddressLike]): string;
    decodeFunctionResult(functionFragment: "acceptSubscriptionOwnerTransfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addConsumer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "cancelSubscription", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createSubscription", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fulfillRandomWords", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fundSubscription", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fundSubscriptionWithNative", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getActiveSubscriptionIds", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getSubscription", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pendingRequestExists", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeConsumer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requestRandomWords", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requestSubscriptionOwnerTransfer", data: BytesLike): Result;
}
export declare namespace RandomWordsFulfilledEvent {
    type InputTuple = [requestId: BigNumberish, success: boolean];
    type OutputTuple = [requestId: bigint, success: boolean];
    interface OutputObject {
        requestId: bigint;
        success: boolean;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RandomWordsRequestedEvent {
    type InputTuple = [
        keyHash: BytesLike,
        requestId: BigNumberish,
        subId: BigNumberish,
        minimumRequestConfirmations: BigNumberish,
        callbackGasLimit: BigNumberish,
        numWords: BigNumberish,
        sender: AddressLike
    ];
    type OutputTuple = [
        keyHash: string,
        requestId: bigint,
        subId: bigint,
        minimumRequestConfirmations: bigint,
        callbackGasLimit: bigint,
        numWords: bigint,
        sender: string
    ];
    interface OutputObject {
        keyHash: string;
        requestId: bigint;
        subId: bigint;
        minimumRequestConfirmations: bigint;
        callbackGasLimit: bigint;
        numWords: bigint;
        sender: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface ChainlinkVRFCoordinatorV2Mock extends BaseContract {
    connect(runner?: ContractRunner | null): ChainlinkVRFCoordinatorV2Mock;
    waitForDeployment(): Promise<this>;
    interface: ChainlinkVRFCoordinatorV2MockInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    acceptSubscriptionOwnerTransfer: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        void
    ], "view">;
    addConsumer: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    cancelSubscription: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    createSubscription: TypedContractMethod<[], [bigint], "view">;
    fulfillRandomWords: TypedContractMethod<[
        _requestId: BigNumberish,
        _consumer: AddressLike,
        _words: BigNumberish[]
    ], [
        void
    ], "nonpayable">;
    fundSubscription: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: BigNumberish
    ], [
        void
    ], "view">;
    fundSubscriptionWithNative: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        void
    ], "payable">;
    getActiveSubscriptionIds: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: BigNumberish
    ], [
        bigint[]
    ], "view">;
    getSubscription: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        [bigint, bigint, bigint, string, string[]]
    ], "view">;
    pendingRequestExists: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        boolean
    ], "view">;
    removeConsumer: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    requestRandomWords: TypedContractMethod<[
        req: VRFV2PlusClient.RandomWordsRequestStruct
    ], [
        bigint
    ], "nonpayable">;
    requestSubscriptionOwnerTransfer: TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "acceptSubscriptionOwnerTransfer"): TypedContractMethod<[arg0: BigNumberish], [void], "view">;
    getFunction(nameOrSignature: "addConsumer"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    getFunction(nameOrSignature: "cancelSubscription"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    getFunction(nameOrSignature: "createSubscription"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "fulfillRandomWords"): TypedContractMethod<[
        _requestId: BigNumberish,
        _consumer: AddressLike,
        _words: BigNumberish[]
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "fundSubscription"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: BigNumberish
    ], [
        void
    ], "view">;
    getFunction(nameOrSignature: "fundSubscriptionWithNative"): TypedContractMethod<[arg0: BigNumberish], [void], "payable">;
    getFunction(nameOrSignature: "getActiveSubscriptionIds"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: BigNumberish
    ], [
        bigint[]
    ], "view">;
    getFunction(nameOrSignature: "getSubscription"): TypedContractMethod<[
        arg0: BigNumberish
    ], [
        [bigint, bigint, bigint, string, string[]]
    ], "view">;
    getFunction(nameOrSignature: "pendingRequestExists"): TypedContractMethod<[arg0: BigNumberish], [boolean], "view">;
    getFunction(nameOrSignature: "removeConsumer"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    getFunction(nameOrSignature: "requestRandomWords"): TypedContractMethod<[
        req: VRFV2PlusClient.RandomWordsRequestStruct
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "requestSubscriptionOwnerTransfer"): TypedContractMethod<[
        arg0: BigNumberish,
        arg1: AddressLike
    ], [
        void
    ], "view">;
    getEvent(key: "RandomWordsFulfilled"): TypedContractEvent<RandomWordsFulfilledEvent.InputTuple, RandomWordsFulfilledEvent.OutputTuple, RandomWordsFulfilledEvent.OutputObject>;
    getEvent(key: "RandomWordsRequested"): TypedContractEvent<RandomWordsRequestedEvent.InputTuple, RandomWordsRequestedEvent.OutputTuple, RandomWordsRequestedEvent.OutputObject>;
    filters: {
        "RandomWordsFulfilled(uint256,bool)": TypedContractEvent<RandomWordsFulfilledEvent.InputTuple, RandomWordsFulfilledEvent.OutputTuple, RandomWordsFulfilledEvent.OutputObject>;
        RandomWordsFulfilled: TypedContractEvent<RandomWordsFulfilledEvent.InputTuple, RandomWordsFulfilledEvent.OutputTuple, RandomWordsFulfilledEvent.OutputObject>;
        "RandomWordsRequested(bytes32,uint256,uint256,uint16,uint32,uint32,address)": TypedContractEvent<RandomWordsRequestedEvent.InputTuple, RandomWordsRequestedEvent.OutputTuple, RandomWordsRequestedEvent.OutputObject>;
        RandomWordsRequested: TypedContractEvent<RandomWordsRequestedEvent.InputTuple, RandomWordsRequestedEvent.OutputTuple, RandomWordsRequestedEvent.OutputObject>;
    };
}
